=======
Credits
=======

First Author
------------

* Phlip

Development Lead
----------------

* Jakub STOLARSKI (dryobates) <jakub.stolarski@gmail.com>

Contributors
------------

* Iza STOLARSKA (izabeera)
* Michael SOUZA (midnighteuler)
